# -*- coding: utf-8 -*-
# flake8: noqa
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: protos/ydb_cms.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ydb._grpc.v3.protos import ydb_operation_pb2 as protos_dot_ydb__operation__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='protos/ydb_cms.proto',
  package='Ydb.Cms',
  syntax='proto3',
  serialized_options=b'\n\022tech.ydb.proto.cmsZ6github.com/ydb-platform/ydb-go-genproto/protos/Ydb_Cms\370\001\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x14protos/ydb_cms.proto\x12\x07Ydb.Cms\x1a\x1aprotos/ydb_operation.proto\"0\n\x0cStorageUnits\x12\x11\n\tunit_kind\x18\x01 \x01(\t\x12\r\n\x05\x63ount\x18\x02 \x01(\x04\"Q\n\x12\x43omputationalUnits\x12\x11\n\tunit_kind\x18\x01 \x01(\t\x12\x19\n\x11\x61vailability_zone\x18\x02 \x01(\t\x12\r\n\x05\x63ount\x18\x03 \x01(\x04\"K\n\x1a\x41llocatedComputationalUnit\x12\x0c\n\x04host\x18\x01 \x01(\t\x12\x0c\n\x04port\x18\x02 \x01(\r\x12\x11\n\tunit_kind\x18\x03 \x01(\t\"s\n\tResources\x12,\n\rstorage_units\x18\x01 \x03(\x0b\x32\x15.Ydb.Cms.StorageUnits\x12\x38\n\x13\x63omputational_units\x18\x02 \x03(\x0b\x32\x1b.Ydb.Cms.ComputationalUnits\"3\n\x13ServerlessResources\x12\x1c\n\x14shared_database_path\x18\x01 \x01(\t\"j\n\x0f\x44\x61tabaseOptions\x12\x1a\n\x12\x64isable_tx_service\x18\x01 \x01(\x08\x12\"\n\x1a\x64isable_external_subdomain\x18\x02 \x01(\x08\x12\x17\n\x0fplan_resolution\x18\x03 \x01(\r\"\x9c\x01\n\x15SchemaOperationQuotas\x12G\n\x13leaky_bucket_quotas\x18\x01 \x03(\x0b\x32*.Ydb.Cms.SchemaOperationQuotas.LeakyBucket\x1a:\n\x0bLeakyBucket\x12\x13\n\x0b\x62ucket_size\x18\x01 \x01(\x01\x12\x16\n\x0e\x62ucket_seconds\x18\x02 \x01(\x04\"\xc0\x01\n\x0e\x44\x61tabaseQuotas\x12\x1c\n\x14\x64\x61ta_size_hard_quota\x18\x01 \x01(\x04\x12\x1c\n\x14\x64\x61ta_size_soft_quota\x18\x02 \x01(\x04\x12 \n\x18\x64\x61ta_stream_shards_quota\x18\x03 \x01(\x04\x12*\n\"data_stream_reserved_storage_quota\x18\x05 \x01(\x04\x12$\n\x1cttl_min_run_internal_seconds\x18\x04 \x01(\r\"\xb7\x04\n\x15\x43reateDatabaseRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x0c\n\x04path\x18\x02 \x01(\t\x12\'\n\tresources\x18\x03 \x01(\x0b\x32\x12.Ydb.Cms.ResourcesH\x00\x12.\n\x10shared_resources\x18\x06 \x01(\x0b\x32\x12.Ydb.Cms.ResourcesH\x00\x12<\n\x14serverless_resources\x18\x07 \x01(\x0b\x32\x1c.Ydb.Cms.ServerlessResourcesH\x00\x12)\n\x07options\x18\x04 \x01(\x0b\x32\x18.Ydb.Cms.DatabaseOptions\x12\x42\n\nattributes\x18\x05 \x03(\x0b\x32..Ydb.Cms.CreateDatabaseRequest.AttributesEntry\x12?\n\x17schema_operation_quotas\x18\x08 \x01(\x0b\x32\x1e.Ydb.Cms.SchemaOperationQuotas\x12\x17\n\x0fidempotency_key\x18\t \x01(\t\x12\x30\n\x0f\x64\x61tabase_quotas\x18\n \x01(\x0b\x32\x17.Ydb.Cms.DatabaseQuotas\x1a\x31\n\x0f\x41ttributesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\x10\n\x0eresources_kind\"F\n\x16\x43reateDatabaseResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"c\n\x18GetDatabaseStatusRequest\x12\x0c\n\x04path\x18\x01 \x01(\t\x12\x39\n\x10operation_params\x18\x02 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\"I\n\x19GetDatabaseStatusResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"\x85\x05\n\x17GetDatabaseStatusResult\x12\x0c\n\x04path\x18\x01 \x01(\t\x12\x35\n\x05state\x18\x02 \x01(\x0e\x32&.Ydb.Cms.GetDatabaseStatusResult.State\x12\x30\n\x12required_resources\x18\x03 \x01(\x0b\x32\x12.Ydb.Cms.ResourcesH\x00\x12\x37\n\x19required_shared_resources\x18\x07 \x01(\x0b\x32\x12.Ydb.Cms.ResourcesH\x00\x12<\n\x14serverless_resources\x18\x08 \x01(\x0b\x32\x1c.Ydb.Cms.ServerlessResourcesH\x00\x12/\n\x13\x61llocated_resources\x18\x04 \x01(\x0b\x32\x12.Ydb.Cms.Resources\x12\x41\n\x14registered_resources\x18\x05 \x03(\x0b\x32#.Ydb.Cms.AllocatedComputationalUnit\x12\x12\n\ngeneration\x18\x06 \x01(\x04\x12?\n\x17schema_operation_quotas\x18\t \x01(\x0b\x32\x1e.Ydb.Cms.SchemaOperationQuotas\x12\x30\n\x0f\x64\x61tabase_quotas\x18\n \x01(\x0b\x32\x17.Ydb.Cms.DatabaseQuotas\"o\n\x05State\x12\x15\n\x11STATE_UNSPECIFIED\x10\x00\x12\x0c\n\x08\x43REATING\x10\x01\x12\x0b\n\x07RUNNING\x10\x02\x12\x0c\n\x08REMOVING\x10\x03\x12\x15\n\x11PENDING_RESOURCES\x10\x04\x12\x0f\n\x0b\x43ONFIGURING\x10\x05\x42\x10\n\x0eresources_kind\"\xdd\x05\n\x14\x41lterDatabaseRequest\x12\x0c\n\x04path\x18\x01 \x01(\t\x12?\n\x1a\x63omputational_units_to_add\x18\x02 \x03(\x0b\x32\x1b.Ydb.Cms.ComputationalUnits\x12\x42\n\x1d\x63omputational_units_to_remove\x18\x03 \x03(\x0b\x32\x1b.Ydb.Cms.ComputationalUnits\x12\x33\n\x14storage_units_to_add\x18\x04 \x03(\x0b\x32\x15.Ydb.Cms.StorageUnits\x12L\n\x1f\x63omputational_units_to_register\x18\x05 \x03(\x0b\x32#.Ydb.Cms.AllocatedComputationalUnit\x12N\n!computational_units_to_deregister\x18\x06 \x03(\x0b\x32#.Ydb.Cms.AllocatedComputationalUnit\x12\x39\n\x10operation_params\x18\x07 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x12\n\ngeneration\x18\x08 \x01(\x04\x12?\n\x17schema_operation_quotas\x18\t \x01(\x0b\x32\x1e.Ydb.Cms.SchemaOperationQuotas\x12\x17\n\x0fidempotency_key\x18\n \x01(\t\x12\x30\n\x0f\x64\x61tabase_quotas\x18\x0b \x01(\x0b\x32\x17.Ydb.Cms.DatabaseQuotas\x12L\n\x10\x61lter_attributes\x18\x0c \x03(\x0b\x32\x32.Ydb.Cms.AlterDatabaseRequest.AlterAttributesEntry\x1a\x36\n\x14\x41lterAttributesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"E\n\x15\x41lterDatabaseResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"Q\n\x14ListDatabasesRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\"E\n\x15ListDatabasesResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"$\n\x13ListDatabasesResult\x12\r\n\x05paths\x18\x01 \x03(\t\"`\n\x15RemoveDatabaseRequest\x12\x0c\n\x04path\x18\x01 \x01(\t\x12\x39\n\x10operation_params\x18\x02 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\"F\n\x16RemoveDatabaseResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"\x92\x01\n\x16StorageUnitDescription\x12\x0c\n\x04kind\x18\x01 \x01(\t\x12;\n\x06labels\x18\x02 \x03(\x0b\x32+.Ydb.Cms.StorageUnitDescription.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x9c\x01\n\x1b\x41vailabilityZoneDescription\x12\x0c\n\x04name\x18\x01 \x01(\t\x12@\n\x06labels\x18\x02 \x03(\x0b\x32\x30.Ydb.Cms.AvailabilityZoneDescription.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xc2\x01\n\x1c\x43omputationalUnitDescription\x12\x0c\n\x04kind\x18\x01 \x01(\t\x12\x41\n\x06labels\x18\x02 \x03(\x0b\x32\x31.Ydb.Cms.ComputationalUnitDescription.LabelsEntry\x12\"\n\x1a\x61llowed_availability_zones\x18\x03 \x03(\t\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"[\n\x1e\x44\x65scribeDatabaseOptionsRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\"O\n\x1f\x44\x65scribeDatabaseOptionsResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"\xdd\x01\n\x1d\x44\x65scribeDatabaseOptionsResult\x12\x36\n\rstorage_units\x18\x01 \x03(\x0b\x32\x1f.Ydb.Cms.StorageUnitDescription\x12@\n\x12\x61vailability_zones\x18\x02 \x03(\x0b\x32$.Ydb.Cms.AvailabilityZoneDescription\x12\x42\n\x13\x63omputational_units\x18\x03 \x03(\x0b\x32%.Ydb.Cms.ComputationalUnitDescriptionBO\n\x12tech.ydb.proto.cmsZ6github.com/ydb-platform/ydb-go-genproto/protos/Ydb_Cms\xf8\x01\x01\x62\x06proto3'
  ,
  dependencies=[protos_dot_ydb__operation__pb2.DESCRIPTOR,])



_GETDATABASESTATUSRESULT_STATE = _descriptor.EnumDescriptor(
  name='State',
  full_name='Ydb.Cms.GetDatabaseStatusResult.State',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='STATE_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CREATING', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RUNNING', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='REMOVING', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PENDING_RESOURCES', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CONFIGURING', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2238,
  serialized_end=2349,
)
_sym_db.RegisterEnumDescriptor(_GETDATABASESTATUSRESULT_STATE)


_STORAGEUNITS = _descriptor.Descriptor(
  name='StorageUnits',
  full_name='Ydb.Cms.StorageUnits',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='unit_kind', full_name='Ydb.Cms.StorageUnits.unit_kind', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='count', full_name='Ydb.Cms.StorageUnits.count', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=61,
  serialized_end=109,
)


_COMPUTATIONALUNITS = _descriptor.Descriptor(
  name='ComputationalUnits',
  full_name='Ydb.Cms.ComputationalUnits',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='unit_kind', full_name='Ydb.Cms.ComputationalUnits.unit_kind', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='availability_zone', full_name='Ydb.Cms.ComputationalUnits.availability_zone', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='count', full_name='Ydb.Cms.ComputationalUnits.count', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=111,
  serialized_end=192,
)


_ALLOCATEDCOMPUTATIONALUNIT = _descriptor.Descriptor(
  name='AllocatedComputationalUnit',
  full_name='Ydb.Cms.AllocatedComputationalUnit',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='host', full_name='Ydb.Cms.AllocatedComputationalUnit.host', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='port', full_name='Ydb.Cms.AllocatedComputationalUnit.port', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='unit_kind', full_name='Ydb.Cms.AllocatedComputationalUnit.unit_kind', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=194,
  serialized_end=269,
)


_RESOURCES = _descriptor.Descriptor(
  name='Resources',
  full_name='Ydb.Cms.Resources',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='storage_units', full_name='Ydb.Cms.Resources.storage_units', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='computational_units', full_name='Ydb.Cms.Resources.computational_units', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=271,
  serialized_end=386,
)


_SERVERLESSRESOURCES = _descriptor.Descriptor(
  name='ServerlessResources',
  full_name='Ydb.Cms.ServerlessResources',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='shared_database_path', full_name='Ydb.Cms.ServerlessResources.shared_database_path', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=388,
  serialized_end=439,
)


_DATABASEOPTIONS = _descriptor.Descriptor(
  name='DatabaseOptions',
  full_name='Ydb.Cms.DatabaseOptions',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='disable_tx_service', full_name='Ydb.Cms.DatabaseOptions.disable_tx_service', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='disable_external_subdomain', full_name='Ydb.Cms.DatabaseOptions.disable_external_subdomain', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='plan_resolution', full_name='Ydb.Cms.DatabaseOptions.plan_resolution', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=441,
  serialized_end=547,
)


_SCHEMAOPERATIONQUOTAS_LEAKYBUCKET = _descriptor.Descriptor(
  name='LeakyBucket',
  full_name='Ydb.Cms.SchemaOperationQuotas.LeakyBucket',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='bucket_size', full_name='Ydb.Cms.SchemaOperationQuotas.LeakyBucket.bucket_size', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bucket_seconds', full_name='Ydb.Cms.SchemaOperationQuotas.LeakyBucket.bucket_seconds', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=648,
  serialized_end=706,
)

_SCHEMAOPERATIONQUOTAS = _descriptor.Descriptor(
  name='SchemaOperationQuotas',
  full_name='Ydb.Cms.SchemaOperationQuotas',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='leaky_bucket_quotas', full_name='Ydb.Cms.SchemaOperationQuotas.leaky_bucket_quotas', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_SCHEMAOPERATIONQUOTAS_LEAKYBUCKET, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=550,
  serialized_end=706,
)


_DATABASEQUOTAS = _descriptor.Descriptor(
  name='DatabaseQuotas',
  full_name='Ydb.Cms.DatabaseQuotas',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='data_size_hard_quota', full_name='Ydb.Cms.DatabaseQuotas.data_size_hard_quota', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data_size_soft_quota', full_name='Ydb.Cms.DatabaseQuotas.data_size_soft_quota', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data_stream_shards_quota', full_name='Ydb.Cms.DatabaseQuotas.data_stream_shards_quota', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data_stream_reserved_storage_quota', full_name='Ydb.Cms.DatabaseQuotas.data_stream_reserved_storage_quota', index=3,
      number=5, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ttl_min_run_internal_seconds', full_name='Ydb.Cms.DatabaseQuotas.ttl_min_run_internal_seconds', index=4,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=709,
  serialized_end=901,
)


_CREATEDATABASEREQUEST_ATTRIBUTESENTRY = _descriptor.Descriptor(
  name='AttributesEntry',
  full_name='Ydb.Cms.CreateDatabaseRequest.AttributesEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='Ydb.Cms.CreateDatabaseRequest.AttributesEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='Ydb.Cms.CreateDatabaseRequest.AttributesEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1404,
  serialized_end=1453,
)

_CREATEDATABASEREQUEST = _descriptor.Descriptor(
  name='CreateDatabaseRequest',
  full_name='Ydb.Cms.CreateDatabaseRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation_params', full_name='Ydb.Cms.CreateDatabaseRequest.operation_params', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='path', full_name='Ydb.Cms.CreateDatabaseRequest.path', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resources', full_name='Ydb.Cms.CreateDatabaseRequest.resources', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='shared_resources', full_name='Ydb.Cms.CreateDatabaseRequest.shared_resources', index=3,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='serverless_resources', full_name='Ydb.Cms.CreateDatabaseRequest.serverless_resources', index=4,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='options', full_name='Ydb.Cms.CreateDatabaseRequest.options', index=5,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='attributes', full_name='Ydb.Cms.CreateDatabaseRequest.attributes', index=6,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='schema_operation_quotas', full_name='Ydb.Cms.CreateDatabaseRequest.schema_operation_quotas', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='idempotency_key', full_name='Ydb.Cms.CreateDatabaseRequest.idempotency_key', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='database_quotas', full_name='Ydb.Cms.CreateDatabaseRequest.database_quotas', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CREATEDATABASEREQUEST_ATTRIBUTESENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='resources_kind', full_name='Ydb.Cms.CreateDatabaseRequest.resources_kind',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=904,
  serialized_end=1471,
)


_CREATEDATABASERESPONSE = _descriptor.Descriptor(
  name='CreateDatabaseResponse',
  full_name='Ydb.Cms.CreateDatabaseResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation', full_name='Ydb.Cms.CreateDatabaseResponse.operation', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1473,
  serialized_end=1543,
)


_GETDATABASESTATUSREQUEST = _descriptor.Descriptor(
  name='GetDatabaseStatusRequest',
  full_name='Ydb.Cms.GetDatabaseStatusRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='path', full_name='Ydb.Cms.GetDatabaseStatusRequest.path', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='operation_params', full_name='Ydb.Cms.GetDatabaseStatusRequest.operation_params', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1545,
  serialized_end=1644,
)


_GETDATABASESTATUSRESPONSE = _descriptor.Descriptor(
  name='GetDatabaseStatusResponse',
  full_name='Ydb.Cms.GetDatabaseStatusResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation', full_name='Ydb.Cms.GetDatabaseStatusResponse.operation', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1646,
  serialized_end=1719,
)


_GETDATABASESTATUSRESULT = _descriptor.Descriptor(
  name='GetDatabaseStatusResult',
  full_name='Ydb.Cms.GetDatabaseStatusResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='path', full_name='Ydb.Cms.GetDatabaseStatusResult.path', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='state', full_name='Ydb.Cms.GetDatabaseStatusResult.state', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='required_resources', full_name='Ydb.Cms.GetDatabaseStatusResult.required_resources', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='required_shared_resources', full_name='Ydb.Cms.GetDatabaseStatusResult.required_shared_resources', index=3,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='serverless_resources', full_name='Ydb.Cms.GetDatabaseStatusResult.serverless_resources', index=4,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='allocated_resources', full_name='Ydb.Cms.GetDatabaseStatusResult.allocated_resources', index=5,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='registered_resources', full_name='Ydb.Cms.GetDatabaseStatusResult.registered_resources', index=6,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='generation', full_name='Ydb.Cms.GetDatabaseStatusResult.generation', index=7,
      number=6, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='schema_operation_quotas', full_name='Ydb.Cms.GetDatabaseStatusResult.schema_operation_quotas', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='database_quotas', full_name='Ydb.Cms.GetDatabaseStatusResult.database_quotas', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _GETDATABASESTATUSRESULT_STATE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='resources_kind', full_name='Ydb.Cms.GetDatabaseStatusResult.resources_kind',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=1722,
  serialized_end=2367,
)


_ALTERDATABASEREQUEST_ALTERATTRIBUTESENTRY = _descriptor.Descriptor(
  name='AlterAttributesEntry',
  full_name='Ydb.Cms.AlterDatabaseRequest.AlterAttributesEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='Ydb.Cms.AlterDatabaseRequest.AlterAttributesEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='Ydb.Cms.AlterDatabaseRequest.AlterAttributesEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3049,
  serialized_end=3103,
)

_ALTERDATABASEREQUEST = _descriptor.Descriptor(
  name='AlterDatabaseRequest',
  full_name='Ydb.Cms.AlterDatabaseRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='path', full_name='Ydb.Cms.AlterDatabaseRequest.path', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='computational_units_to_add', full_name='Ydb.Cms.AlterDatabaseRequest.computational_units_to_add', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='computational_units_to_remove', full_name='Ydb.Cms.AlterDatabaseRequest.computational_units_to_remove', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='storage_units_to_add', full_name='Ydb.Cms.AlterDatabaseRequest.storage_units_to_add', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='computational_units_to_register', full_name='Ydb.Cms.AlterDatabaseRequest.computational_units_to_register', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='computational_units_to_deregister', full_name='Ydb.Cms.AlterDatabaseRequest.computational_units_to_deregister', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='operation_params', full_name='Ydb.Cms.AlterDatabaseRequest.operation_params', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='generation', full_name='Ydb.Cms.AlterDatabaseRequest.generation', index=7,
      number=8, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='schema_operation_quotas', full_name='Ydb.Cms.AlterDatabaseRequest.schema_operation_quotas', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='idempotency_key', full_name='Ydb.Cms.AlterDatabaseRequest.idempotency_key', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='database_quotas', full_name='Ydb.Cms.AlterDatabaseRequest.database_quotas', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='alter_attributes', full_name='Ydb.Cms.AlterDatabaseRequest.alter_attributes', index=11,
      number=12, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_ALTERDATABASEREQUEST_ALTERATTRIBUTESENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2370,
  serialized_end=3103,
)


_ALTERDATABASERESPONSE = _descriptor.Descriptor(
  name='AlterDatabaseResponse',
  full_name='Ydb.Cms.AlterDatabaseResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation', full_name='Ydb.Cms.AlterDatabaseResponse.operation', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3105,
  serialized_end=3174,
)


_LISTDATABASESREQUEST = _descriptor.Descriptor(
  name='ListDatabasesRequest',
  full_name='Ydb.Cms.ListDatabasesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation_params', full_name='Ydb.Cms.ListDatabasesRequest.operation_params', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3176,
  serialized_end=3257,
)


_LISTDATABASESRESPONSE = _descriptor.Descriptor(
  name='ListDatabasesResponse',
  full_name='Ydb.Cms.ListDatabasesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation', full_name='Ydb.Cms.ListDatabasesResponse.operation', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3259,
  serialized_end=3328,
)


_LISTDATABASESRESULT = _descriptor.Descriptor(
  name='ListDatabasesResult',
  full_name='Ydb.Cms.ListDatabasesResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='paths', full_name='Ydb.Cms.ListDatabasesResult.paths', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3330,
  serialized_end=3366,
)


_REMOVEDATABASEREQUEST = _descriptor.Descriptor(
  name='RemoveDatabaseRequest',
  full_name='Ydb.Cms.RemoveDatabaseRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='path', full_name='Ydb.Cms.RemoveDatabaseRequest.path', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='operation_params', full_name='Ydb.Cms.RemoveDatabaseRequest.operation_params', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3368,
  serialized_end=3464,
)


_REMOVEDATABASERESPONSE = _descriptor.Descriptor(
  name='RemoveDatabaseResponse',
  full_name='Ydb.Cms.RemoveDatabaseResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation', full_name='Ydb.Cms.RemoveDatabaseResponse.operation', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3466,
  serialized_end=3536,
)


_STORAGEUNITDESCRIPTION_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='Ydb.Cms.StorageUnitDescription.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='Ydb.Cms.StorageUnitDescription.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='Ydb.Cms.StorageUnitDescription.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3640,
  serialized_end=3685,
)

_STORAGEUNITDESCRIPTION = _descriptor.Descriptor(
  name='StorageUnitDescription',
  full_name='Ydb.Cms.StorageUnitDescription',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='kind', full_name='Ydb.Cms.StorageUnitDescription.kind', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='Ydb.Cms.StorageUnitDescription.labels', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_STORAGEUNITDESCRIPTION_LABELSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3539,
  serialized_end=3685,
)


_AVAILABILITYZONEDESCRIPTION_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='Ydb.Cms.AvailabilityZoneDescription.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='Ydb.Cms.AvailabilityZoneDescription.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='Ydb.Cms.AvailabilityZoneDescription.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3640,
  serialized_end=3685,
)

_AVAILABILITYZONEDESCRIPTION = _descriptor.Descriptor(
  name='AvailabilityZoneDescription',
  full_name='Ydb.Cms.AvailabilityZoneDescription',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='Ydb.Cms.AvailabilityZoneDescription.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='Ydb.Cms.AvailabilityZoneDescription.labels', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_AVAILABILITYZONEDESCRIPTION_LABELSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3688,
  serialized_end=3844,
)


_COMPUTATIONALUNITDESCRIPTION_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='Ydb.Cms.ComputationalUnitDescription.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='Ydb.Cms.ComputationalUnitDescription.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='Ydb.Cms.ComputationalUnitDescription.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3640,
  serialized_end=3685,
)

_COMPUTATIONALUNITDESCRIPTION = _descriptor.Descriptor(
  name='ComputationalUnitDescription',
  full_name='Ydb.Cms.ComputationalUnitDescription',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='kind', full_name='Ydb.Cms.ComputationalUnitDescription.kind', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='Ydb.Cms.ComputationalUnitDescription.labels', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='allowed_availability_zones', full_name='Ydb.Cms.ComputationalUnitDescription.allowed_availability_zones', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_COMPUTATIONALUNITDESCRIPTION_LABELSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3847,
  serialized_end=4041,
)


_DESCRIBEDATABASEOPTIONSREQUEST = _descriptor.Descriptor(
  name='DescribeDatabaseOptionsRequest',
  full_name='Ydb.Cms.DescribeDatabaseOptionsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation_params', full_name='Ydb.Cms.DescribeDatabaseOptionsRequest.operation_params', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4043,
  serialized_end=4134,
)


_DESCRIBEDATABASEOPTIONSRESPONSE = _descriptor.Descriptor(
  name='DescribeDatabaseOptionsResponse',
  full_name='Ydb.Cms.DescribeDatabaseOptionsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation', full_name='Ydb.Cms.DescribeDatabaseOptionsResponse.operation', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4136,
  serialized_end=4215,
)


_DESCRIBEDATABASEOPTIONSRESULT = _descriptor.Descriptor(
  name='DescribeDatabaseOptionsResult',
  full_name='Ydb.Cms.DescribeDatabaseOptionsResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='storage_units', full_name='Ydb.Cms.DescribeDatabaseOptionsResult.storage_units', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='availability_zones', full_name='Ydb.Cms.DescribeDatabaseOptionsResult.availability_zones', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='computational_units', full_name='Ydb.Cms.DescribeDatabaseOptionsResult.computational_units', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4218,
  serialized_end=4439,
)

_RESOURCES.fields_by_name['storage_units'].message_type = _STORAGEUNITS
_RESOURCES.fields_by_name['computational_units'].message_type = _COMPUTATIONALUNITS
_SCHEMAOPERATIONQUOTAS_LEAKYBUCKET.containing_type = _SCHEMAOPERATIONQUOTAS
_SCHEMAOPERATIONQUOTAS.fields_by_name['leaky_bucket_quotas'].message_type = _SCHEMAOPERATIONQUOTAS_LEAKYBUCKET
_CREATEDATABASEREQUEST_ATTRIBUTESENTRY.containing_type = _CREATEDATABASEREQUEST
_CREATEDATABASEREQUEST.fields_by_name['operation_params'].message_type = protos_dot_ydb__operation__pb2._OPERATIONPARAMS
_CREATEDATABASEREQUEST.fields_by_name['resources'].message_type = _RESOURCES
_CREATEDATABASEREQUEST.fields_by_name['shared_resources'].message_type = _RESOURCES
_CREATEDATABASEREQUEST.fields_by_name['serverless_resources'].message_type = _SERVERLESSRESOURCES
_CREATEDATABASEREQUEST.fields_by_name['options'].message_type = _DATABASEOPTIONS
_CREATEDATABASEREQUEST.fields_by_name['attributes'].message_type = _CREATEDATABASEREQUEST_ATTRIBUTESENTRY
_CREATEDATABASEREQUEST.fields_by_name['schema_operation_quotas'].message_type = _SCHEMAOPERATIONQUOTAS
_CREATEDATABASEREQUEST.fields_by_name['database_quotas'].message_type = _DATABASEQUOTAS
_CREATEDATABASEREQUEST.oneofs_by_name['resources_kind'].fields.append(
  _CREATEDATABASEREQUEST.fields_by_name['resources'])
_CREATEDATABASEREQUEST.fields_by_name['resources'].containing_oneof = _CREATEDATABASEREQUEST.oneofs_by_name['resources_kind']
_CREATEDATABASEREQUEST.oneofs_by_name['resources_kind'].fields.append(
  _CREATEDATABASEREQUEST.fields_by_name['shared_resources'])
_CREATEDATABASEREQUEST.fields_by_name['shared_resources'].containing_oneof = _CREATEDATABASEREQUEST.oneofs_by_name['resources_kind']
_CREATEDATABASEREQUEST.oneofs_by_name['resources_kind'].fields.append(
  _CREATEDATABASEREQUEST.fields_by_name['serverless_resources'])
_CREATEDATABASEREQUEST.fields_by_name['serverless_resources'].containing_oneof = _CREATEDATABASEREQUEST.oneofs_by_name['resources_kind']
_CREATEDATABASERESPONSE.fields_by_name['operation'].message_type = protos_dot_ydb__operation__pb2._OPERATION
_GETDATABASESTATUSREQUEST.fields_by_name['operation_params'].message_type = protos_dot_ydb__operation__pb2._OPERATIONPARAMS
_GETDATABASESTATUSRESPONSE.fields_by_name['operation'].message_type = protos_dot_ydb__operation__pb2._OPERATION
_GETDATABASESTATUSRESULT.fields_by_name['state'].enum_type = _GETDATABASESTATUSRESULT_STATE
_GETDATABASESTATUSRESULT.fields_by_name['required_resources'].message_type = _RESOURCES
_GETDATABASESTATUSRESULT.fields_by_name['required_shared_resources'].message_type = _RESOURCES
_GETDATABASESTATUSRESULT.fields_by_name['serverless_resources'].message_type = _SERVERLESSRESOURCES
_GETDATABASESTATUSRESULT.fields_by_name['allocated_resources'].message_type = _RESOURCES
_GETDATABASESTATUSRESULT.fields_by_name['registered_resources'].message_type = _ALLOCATEDCOMPUTATIONALUNIT
_GETDATABASESTATUSRESULT.fields_by_name['schema_operation_quotas'].message_type = _SCHEMAOPERATIONQUOTAS
_GETDATABASESTATUSRESULT.fields_by_name['database_quotas'].message_type = _DATABASEQUOTAS
_GETDATABASESTATUSRESULT_STATE.containing_type = _GETDATABASESTATUSRESULT
_GETDATABASESTATUSRESULT.oneofs_by_name['resources_kind'].fields.append(
  _GETDATABASESTATUSRESULT.fields_by_name['required_resources'])
_GETDATABASESTATUSRESULT.fields_by_name['required_resources'].containing_oneof = _GETDATABASESTATUSRESULT.oneofs_by_name['resources_kind']
_GETDATABASESTATUSRESULT.oneofs_by_name['resources_kind'].fields.append(
  _GETDATABASESTATUSRESULT.fields_by_name['required_shared_resources'])
_GETDATABASESTATUSRESULT.fields_by_name['required_shared_resources'].containing_oneof = _GETDATABASESTATUSRESULT.oneofs_by_name['resources_kind']
_GETDATABASESTATUSRESULT.oneofs_by_name['resources_kind'].fields.append(
  _GETDATABASESTATUSRESULT.fields_by_name['serverless_resources'])
_GETDATABASESTATUSRESULT.fields_by_name['serverless_resources'].containing_oneof = _GETDATABASESTATUSRESULT.oneofs_by_name['resources_kind']
_ALTERDATABASEREQUEST_ALTERATTRIBUTESENTRY.containing_type = _ALTERDATABASEREQUEST
_ALTERDATABASEREQUEST.fields_by_name['computational_units_to_add'].message_type = _COMPUTATIONALUNITS
_ALTERDATABASEREQUEST.fields_by_name['computational_units_to_remove'].message_type = _COMPUTATIONALUNITS
_ALTERDATABASEREQUEST.fields_by_name['storage_units_to_add'].message_type = _STORAGEUNITS
_ALTERDATABASEREQUEST.fields_by_name['computational_units_to_register'].message_type = _ALLOCATEDCOMPUTATIONALUNIT
_ALTERDATABASEREQUEST.fields_by_name['computational_units_to_deregister'].message_type = _ALLOCATEDCOMPUTATIONALUNIT
_ALTERDATABASEREQUEST.fields_by_name['operation_params'].message_type = protos_dot_ydb__operation__pb2._OPERATIONPARAMS
_ALTERDATABASEREQUEST.fields_by_name['schema_operation_quotas'].message_type = _SCHEMAOPERATIONQUOTAS
_ALTERDATABASEREQUEST.fields_by_name['database_quotas'].message_type = _DATABASEQUOTAS
_ALTERDATABASEREQUEST.fields_by_name['alter_attributes'].message_type = _ALTERDATABASEREQUEST_ALTERATTRIBUTESENTRY
_ALTERDATABASERESPONSE.fields_by_name['operation'].message_type = protos_dot_ydb__operation__pb2._OPERATION
_LISTDATABASESREQUEST.fields_by_name['operation_params'].message_type = protos_dot_ydb__operation__pb2._OPERATIONPARAMS
_LISTDATABASESRESPONSE.fields_by_name['operation'].message_type = protos_dot_ydb__operation__pb2._OPERATION
_REMOVEDATABASEREQUEST.fields_by_name['operation_params'].message_type = protos_dot_ydb__operation__pb2._OPERATIONPARAMS
_REMOVEDATABASERESPONSE.fields_by_name['operation'].message_type = protos_dot_ydb__operation__pb2._OPERATION
_STORAGEUNITDESCRIPTION_LABELSENTRY.containing_type = _STORAGEUNITDESCRIPTION
_STORAGEUNITDESCRIPTION.fields_by_name['labels'].message_type = _STORAGEUNITDESCRIPTION_LABELSENTRY
_AVAILABILITYZONEDESCRIPTION_LABELSENTRY.containing_type = _AVAILABILITYZONEDESCRIPTION
_AVAILABILITYZONEDESCRIPTION.fields_by_name['labels'].message_type = _AVAILABILITYZONEDESCRIPTION_LABELSENTRY
_COMPUTATIONALUNITDESCRIPTION_LABELSENTRY.containing_type = _COMPUTATIONALUNITDESCRIPTION
_COMPUTATIONALUNITDESCRIPTION.fields_by_name['labels'].message_type = _COMPUTATIONALUNITDESCRIPTION_LABELSENTRY
_DESCRIBEDATABASEOPTIONSREQUEST.fields_by_name['operation_params'].message_type = protos_dot_ydb__operation__pb2._OPERATIONPARAMS
_DESCRIBEDATABASEOPTIONSRESPONSE.fields_by_name['operation'].message_type = protos_dot_ydb__operation__pb2._OPERATION
_DESCRIBEDATABASEOPTIONSRESULT.fields_by_name['storage_units'].message_type = _STORAGEUNITDESCRIPTION
_DESCRIBEDATABASEOPTIONSRESULT.fields_by_name['availability_zones'].message_type = _AVAILABILITYZONEDESCRIPTION
_DESCRIBEDATABASEOPTIONSRESULT.fields_by_name['computational_units'].message_type = _COMPUTATIONALUNITDESCRIPTION
DESCRIPTOR.message_types_by_name['StorageUnits'] = _STORAGEUNITS
DESCRIPTOR.message_types_by_name['ComputationalUnits'] = _COMPUTATIONALUNITS
DESCRIPTOR.message_types_by_name['AllocatedComputationalUnit'] = _ALLOCATEDCOMPUTATIONALUNIT
DESCRIPTOR.message_types_by_name['Resources'] = _RESOURCES
DESCRIPTOR.message_types_by_name['ServerlessResources'] = _SERVERLESSRESOURCES
DESCRIPTOR.message_types_by_name['DatabaseOptions'] = _DATABASEOPTIONS
DESCRIPTOR.message_types_by_name['SchemaOperationQuotas'] = _SCHEMAOPERATIONQUOTAS
DESCRIPTOR.message_types_by_name['DatabaseQuotas'] = _DATABASEQUOTAS
DESCRIPTOR.message_types_by_name['CreateDatabaseRequest'] = _CREATEDATABASEREQUEST
DESCRIPTOR.message_types_by_name['CreateDatabaseResponse'] = _CREATEDATABASERESPONSE
DESCRIPTOR.message_types_by_name['GetDatabaseStatusRequest'] = _GETDATABASESTATUSREQUEST
DESCRIPTOR.message_types_by_name['GetDatabaseStatusResponse'] = _GETDATABASESTATUSRESPONSE
DESCRIPTOR.message_types_by_name['GetDatabaseStatusResult'] = _GETDATABASESTATUSRESULT
DESCRIPTOR.message_types_by_name['AlterDatabaseRequest'] = _ALTERDATABASEREQUEST
DESCRIPTOR.message_types_by_name['AlterDatabaseResponse'] = _ALTERDATABASERESPONSE
DESCRIPTOR.message_types_by_name['ListDatabasesRequest'] = _LISTDATABASESREQUEST
DESCRIPTOR.message_types_by_name['ListDatabasesResponse'] = _LISTDATABASESRESPONSE
DESCRIPTOR.message_types_by_name['ListDatabasesResult'] = _LISTDATABASESRESULT
DESCRIPTOR.message_types_by_name['RemoveDatabaseRequest'] = _REMOVEDATABASEREQUEST
DESCRIPTOR.message_types_by_name['RemoveDatabaseResponse'] = _REMOVEDATABASERESPONSE
DESCRIPTOR.message_types_by_name['StorageUnitDescription'] = _STORAGEUNITDESCRIPTION
DESCRIPTOR.message_types_by_name['AvailabilityZoneDescription'] = _AVAILABILITYZONEDESCRIPTION
DESCRIPTOR.message_types_by_name['ComputationalUnitDescription'] = _COMPUTATIONALUNITDESCRIPTION
DESCRIPTOR.message_types_by_name['DescribeDatabaseOptionsRequest'] = _DESCRIBEDATABASEOPTIONSREQUEST
DESCRIPTOR.message_types_by_name['DescribeDatabaseOptionsResponse'] = _DESCRIBEDATABASEOPTIONSRESPONSE
DESCRIPTOR.message_types_by_name['DescribeDatabaseOptionsResult'] = _DESCRIBEDATABASEOPTIONSRESULT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

StorageUnits = _reflection.GeneratedProtocolMessageType('StorageUnits', (_message.Message,), {
  'DESCRIPTOR' : _STORAGEUNITS,
  '__module__' : 'protos.ydb_cms_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Cms.StorageUnits)
  })
_sym_db.RegisterMessage(StorageUnits)

ComputationalUnits = _reflection.GeneratedProtocolMessageType('ComputationalUnits', (_message.Message,), {
  'DESCRIPTOR' : _COMPUTATIONALUNITS,
  '__module__' : 'protos.ydb_cms_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Cms.ComputationalUnits)
  })
_sym_db.RegisterMessage(ComputationalUnits)

AllocatedComputationalUnit = _reflection.GeneratedProtocolMessageType('AllocatedComputationalUnit', (_message.Message,), {
  'DESCRIPTOR' : _ALLOCATEDCOMPUTATIONALUNIT,
  '__module__' : 'protos.ydb_cms_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Cms.AllocatedComputationalUnit)
  })
_sym_db.RegisterMessage(AllocatedComputationalUnit)

Resources = _reflection.GeneratedProtocolMessageType('Resources', (_message.Message,), {
  'DESCRIPTOR' : _RESOURCES,
  '__module__' : 'protos.ydb_cms_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Cms.Resources)
  })
_sym_db.RegisterMessage(Resources)

ServerlessResources = _reflection.GeneratedProtocolMessageType('ServerlessResources', (_message.Message,), {
  'DESCRIPTOR' : _SERVERLESSRESOURCES,
  '__module__' : 'protos.ydb_cms_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Cms.ServerlessResources)
  })
_sym_db.RegisterMessage(ServerlessResources)

DatabaseOptions = _reflection.GeneratedProtocolMessageType('DatabaseOptions', (_message.Message,), {
  'DESCRIPTOR' : _DATABASEOPTIONS,
  '__module__' : 'protos.ydb_cms_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Cms.DatabaseOptions)
  })
_sym_db.RegisterMessage(DatabaseOptions)

SchemaOperationQuotas = _reflection.GeneratedProtocolMessageType('SchemaOperationQuotas', (_message.Message,), {

  'LeakyBucket' : _reflection.GeneratedProtocolMessageType('LeakyBucket', (_message.Message,), {
    'DESCRIPTOR' : _SCHEMAOPERATIONQUOTAS_LEAKYBUCKET,
    '__module__' : 'protos.ydb_cms_pb2'
    # @@protoc_insertion_point(class_scope:Ydb.Cms.SchemaOperationQuotas.LeakyBucket)
    })
  ,
  'DESCRIPTOR' : _SCHEMAOPERATIONQUOTAS,
  '__module__' : 'protos.ydb_cms_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Cms.SchemaOperationQuotas)
  })
_sym_db.RegisterMessage(SchemaOperationQuotas)
_sym_db.RegisterMessage(SchemaOperationQuotas.LeakyBucket)

DatabaseQuotas = _reflection.GeneratedProtocolMessageType('DatabaseQuotas', (_message.Message,), {
  'DESCRIPTOR' : _DATABASEQUOTAS,
  '__module__' : 'protos.ydb_cms_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Cms.DatabaseQuotas)
  })
_sym_db.RegisterMessage(DatabaseQuotas)

CreateDatabaseRequest = _reflection.GeneratedProtocolMessageType('CreateDatabaseRequest', (_message.Message,), {

  'AttributesEntry' : _reflection.GeneratedProtocolMessageType('AttributesEntry', (_message.Message,), {
    'DESCRIPTOR' : _CREATEDATABASEREQUEST_ATTRIBUTESENTRY,
    '__module__' : 'protos.ydb_cms_pb2'
    # @@protoc_insertion_point(class_scope:Ydb.Cms.CreateDatabaseRequest.AttributesEntry)
    })
  ,
  'DESCRIPTOR' : _CREATEDATABASEREQUEST,
  '__module__' : 'protos.ydb_cms_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Cms.CreateDatabaseRequest)
  })
_sym_db.RegisterMessage(CreateDatabaseRequest)
_sym_db.RegisterMessage(CreateDatabaseRequest.AttributesEntry)

CreateDatabaseResponse = _reflection.GeneratedProtocolMessageType('CreateDatabaseResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATEDATABASERESPONSE,
  '__module__' : 'protos.ydb_cms_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Cms.CreateDatabaseResponse)
  })
_sym_db.RegisterMessage(CreateDatabaseResponse)

GetDatabaseStatusRequest = _reflection.GeneratedProtocolMessageType('GetDatabaseStatusRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETDATABASESTATUSREQUEST,
  '__module__' : 'protos.ydb_cms_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Cms.GetDatabaseStatusRequest)
  })
_sym_db.RegisterMessage(GetDatabaseStatusRequest)

GetDatabaseStatusResponse = _reflection.GeneratedProtocolMessageType('GetDatabaseStatusResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETDATABASESTATUSRESPONSE,
  '__module__' : 'protos.ydb_cms_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Cms.GetDatabaseStatusResponse)
  })
_sym_db.RegisterMessage(GetDatabaseStatusResponse)

GetDatabaseStatusResult = _reflection.GeneratedProtocolMessageType('GetDatabaseStatusResult', (_message.Message,), {
  'DESCRIPTOR' : _GETDATABASESTATUSRESULT,
  '__module__' : 'protos.ydb_cms_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Cms.GetDatabaseStatusResult)
  })
_sym_db.RegisterMessage(GetDatabaseStatusResult)

AlterDatabaseRequest = _reflection.GeneratedProtocolMessageType('AlterDatabaseRequest', (_message.Message,), {

  'AlterAttributesEntry' : _reflection.GeneratedProtocolMessageType('AlterAttributesEntry', (_message.Message,), {
    'DESCRIPTOR' : _ALTERDATABASEREQUEST_ALTERATTRIBUTESENTRY,
    '__module__' : 'protos.ydb_cms_pb2'
    # @@protoc_insertion_point(class_scope:Ydb.Cms.AlterDatabaseRequest.AlterAttributesEntry)
    })
  ,
  'DESCRIPTOR' : _ALTERDATABASEREQUEST,
  '__module__' : 'protos.ydb_cms_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Cms.AlterDatabaseRequest)
  })
_sym_db.RegisterMessage(AlterDatabaseRequest)
_sym_db.RegisterMessage(AlterDatabaseRequest.AlterAttributesEntry)

AlterDatabaseResponse = _reflection.GeneratedProtocolMessageType('AlterDatabaseResponse', (_message.Message,), {
  'DESCRIPTOR' : _ALTERDATABASERESPONSE,
  '__module__' : 'protos.ydb_cms_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Cms.AlterDatabaseResponse)
  })
_sym_db.RegisterMessage(AlterDatabaseResponse)

ListDatabasesRequest = _reflection.GeneratedProtocolMessageType('ListDatabasesRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTDATABASESREQUEST,
  '__module__' : 'protos.ydb_cms_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Cms.ListDatabasesRequest)
  })
_sym_db.RegisterMessage(ListDatabasesRequest)

ListDatabasesResponse = _reflection.GeneratedProtocolMessageType('ListDatabasesResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTDATABASESRESPONSE,
  '__module__' : 'protos.ydb_cms_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Cms.ListDatabasesResponse)
  })
_sym_db.RegisterMessage(ListDatabasesResponse)

ListDatabasesResult = _reflection.GeneratedProtocolMessageType('ListDatabasesResult', (_message.Message,), {
  'DESCRIPTOR' : _LISTDATABASESRESULT,
  '__module__' : 'protos.ydb_cms_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Cms.ListDatabasesResult)
  })
_sym_db.RegisterMessage(ListDatabasesResult)

RemoveDatabaseRequest = _reflection.GeneratedProtocolMessageType('RemoveDatabaseRequest', (_message.Message,), {
  'DESCRIPTOR' : _REMOVEDATABASEREQUEST,
  '__module__' : 'protos.ydb_cms_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Cms.RemoveDatabaseRequest)
  })
_sym_db.RegisterMessage(RemoveDatabaseRequest)

RemoveDatabaseResponse = _reflection.GeneratedProtocolMessageType('RemoveDatabaseResponse', (_message.Message,), {
  'DESCRIPTOR' : _REMOVEDATABASERESPONSE,
  '__module__' : 'protos.ydb_cms_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Cms.RemoveDatabaseResponse)
  })
_sym_db.RegisterMessage(RemoveDatabaseResponse)

StorageUnitDescription = _reflection.GeneratedProtocolMessageType('StorageUnitDescription', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _STORAGEUNITDESCRIPTION_LABELSENTRY,
    '__module__' : 'protos.ydb_cms_pb2'
    # @@protoc_insertion_point(class_scope:Ydb.Cms.StorageUnitDescription.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _STORAGEUNITDESCRIPTION,
  '__module__' : 'protos.ydb_cms_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Cms.StorageUnitDescription)
  })
_sym_db.RegisterMessage(StorageUnitDescription)
_sym_db.RegisterMessage(StorageUnitDescription.LabelsEntry)

AvailabilityZoneDescription = _reflection.GeneratedProtocolMessageType('AvailabilityZoneDescription', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _AVAILABILITYZONEDESCRIPTION_LABELSENTRY,
    '__module__' : 'protos.ydb_cms_pb2'
    # @@protoc_insertion_point(class_scope:Ydb.Cms.AvailabilityZoneDescription.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _AVAILABILITYZONEDESCRIPTION,
  '__module__' : 'protos.ydb_cms_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Cms.AvailabilityZoneDescription)
  })
_sym_db.RegisterMessage(AvailabilityZoneDescription)
_sym_db.RegisterMessage(AvailabilityZoneDescription.LabelsEntry)

ComputationalUnitDescription = _reflection.GeneratedProtocolMessageType('ComputationalUnitDescription', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _COMPUTATIONALUNITDESCRIPTION_LABELSENTRY,
    '__module__' : 'protos.ydb_cms_pb2'
    # @@protoc_insertion_point(class_scope:Ydb.Cms.ComputationalUnitDescription.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _COMPUTATIONALUNITDESCRIPTION,
  '__module__' : 'protos.ydb_cms_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Cms.ComputationalUnitDescription)
  })
_sym_db.RegisterMessage(ComputationalUnitDescription)
_sym_db.RegisterMessage(ComputationalUnitDescription.LabelsEntry)

DescribeDatabaseOptionsRequest = _reflection.GeneratedProtocolMessageType('DescribeDatabaseOptionsRequest', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBEDATABASEOPTIONSREQUEST,
  '__module__' : 'protos.ydb_cms_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Cms.DescribeDatabaseOptionsRequest)
  })
_sym_db.RegisterMessage(DescribeDatabaseOptionsRequest)

DescribeDatabaseOptionsResponse = _reflection.GeneratedProtocolMessageType('DescribeDatabaseOptionsResponse', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBEDATABASEOPTIONSRESPONSE,
  '__module__' : 'protos.ydb_cms_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Cms.DescribeDatabaseOptionsResponse)
  })
_sym_db.RegisterMessage(DescribeDatabaseOptionsResponse)

DescribeDatabaseOptionsResult = _reflection.GeneratedProtocolMessageType('DescribeDatabaseOptionsResult', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBEDATABASEOPTIONSRESULT,
  '__module__' : 'protos.ydb_cms_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Cms.DescribeDatabaseOptionsResult)
  })
_sym_db.RegisterMessage(DescribeDatabaseOptionsResult)


DESCRIPTOR._options = None
_CREATEDATABASEREQUEST_ATTRIBUTESENTRY._options = None
_ALTERDATABASEREQUEST_ALTERATTRIBUTESENTRY._options = None
_STORAGEUNITDESCRIPTION_LABELSENTRY._options = None
_AVAILABILITYZONEDESCRIPTION_LABELSENTRY._options = None
_COMPUTATIONALUNITDESCRIPTION_LABELSENTRY._options = None
# @@protoc_insertion_point(module_scope)



from __future__ import annotations

import asyncio
import copy
import dataclasses
import datetime
import gzip
import typing
from queue import Queue, Empty
from typing import List, Callable, Optional
from unittest import mock

import freezegun
import pytest

from .. import aio
from .. import StatusCode, issues
from .._grpc.grpcwrapper.ydb_topic import (
    Codec,
    StreamWriteMessage,
    TransactionIdentity,
    UpdateTokenRequest,
    UpdateTokenResponse,
)
from .._grpc.grpcwrapper.common_utils import ServerStatus
from .topic_writer import (
    InternalMessage,
    PublicMessage,
    WriterSettings,
    PublicWriterSettings,
    PublicWriterInitInfo,
    PublicWriteResult,
    TopicWriterError,
)
from .._grpc.grpcwrapper.ydb_topic_public_types import PublicCodec
from .._topic_common.test_helpers import StreamMock, wait_for_fast

from .topic_writer_asyncio import (
    WriterAsyncIOStream,
    WriterAsyncIOReconnector,
    WriterAsyncIO,
)

from ..credentials import AnonymousCredentials

from .._constants import DEFAULT_INITIAL_RESPONSE_TIMEOUT


FAKE_TRANSACTION_IDENTITY = TransactionIdentity(
    tx_id="transaction_id",
    session_id="session_id",
)


@pytest.fixture
def default_driver() -> aio.Driver:
    driver = mock.Mock(spec=aio.Driver)
    driver._credentials = AnonymousCredentials()
    return driver


@pytest.mark.asyncio
class TestWriterAsyncIOStream:
    @dataclasses.dataclass
    class WriterWithMockedStream:
        writer: WriterAsyncIOStream
        stream: StreamMock

    @pytest.fixture
    def stream(self):
        stream = StreamMock()
        yield stream
        stream.close()

    @staticmethod
    async def get_started_writer(stream, *args, **kwargs) -> WriterAsyncIOStream:
        stream.from_server.put_nowait(
            StreamWriteMessage.InitResponse(
                last_seq_no=4,
                session_id="123",
                partition_id=3,
                supported_codecs=[Codec.CODEC_RAW, Codec.CODEC_GZIP],
                status=ServerStatus(StatusCode.SUCCESS, []),
            )
        )

        writer = WriterAsyncIOStream(*args, **kwargs)
        await writer._start(
            stream,
            init_message=StreamWriteMessage.InitRequest(
                path="/local/test",
                producer_id="producer-id",
                write_session_meta={"a": "b"},
                partitioning=StreamWriteMessage.PartitioningMessageGroupID(message_group_id="message-group-id"),
                get_last_seq_no=False,
            ),
        )
        await stream.from_client.get()
        return writer

    @pytest.fixture
    async def writer_and_stream(self, stream) -> WriterWithMockedStream:
        writer = await self.get_started_writer(stream)

        yield TestWriterAsyncIOStream.WriterWithMockedStream(
            stream=stream,
            writer=writer,
        )

        await writer.close()

    async def test_init_writer(self, stream):
        init_seqno = 4
        init_message = StreamWriteMessage.InitRequest(
            path="/local/test",
            producer_id="producer-id",
            write_session_meta={"a": "b"},
            partitioning=StreamWriteMessage.PartitioningMessageGroupID(message_group_id="message-group-id"),
            get_last_seq_no=False,
        )
        stream.from_server.put_nowait(
            StreamWriteMessage.InitResponse(
                last_seq_no=init_seqno,
                session_id="123",
                partition_id=0,
                supported_codecs=[],
                status=ServerStatus(StatusCode.SUCCESS, []),
            )
        )

        writer = WriterAsyncIOStream()
        await writer._start(stream, init_message)

        sent_message = await stream.from_client.get()
        expected_message = StreamWriteMessage.FromClient(init_message)

        assert expected_message == sent_message
        assert writer.last_seqno == init_seqno

        await writer.close()

    async def test_write_a_message(self, writer_and_stream: WriterWithMockedStream):
        data = "123".encode()
        now = datetime.datetime.now(datetime.timezone.utc)
        writer_and_stream.writer.write(
            [
                InternalMessage(
                    PublicMessage(
                        seqno=1,
                        created_at=now,
                        data=data,
                    )
                )
            ]
        )

        expected_message = StreamWriteMessage.FromClient(
            StreamWriteMessage.WriteRequest(
                codec=Codec.CODEC_RAW,
                tx_identity=None,
                messages=[
                    StreamWriteMessage.WriteRequest.MessageData(
                        seq_no=1,
                        created_at=now,
                        data=data,
                        metadata_items={},
                        uncompressed_size=len(data),
                        partitioning=None,
                    )
                ],
            )
        )

        sent_message = await writer_and_stream.stream.from_client.get()
        assert expected_message == sent_message

    async def test_write_a_message_with_tx(self, writer_and_stream: WriterWithMockedStream):
        writer_and_stream.writer._tx_identity = FAKE_TRANSACTION_IDENTITY

        data = "123".encode()
        now = datetime.datetime.now(datetime.timezone.utc)
        writer_and_stream.writer.write(
            [
                InternalMessage(
                    PublicMessage(
                        seqno=1,
                        created_at=now,
                        data=data,
                    )
                )
            ]
        )

        expected_message = StreamWriteMessage.FromClient(
            StreamWriteMessage.WriteRequest(
                codec=Codec.CODEC_RAW,
                tx_identity=FAKE_TRANSACTION_IDENTITY,
                messages=[
                    StreamWriteMessage.WriteRequest.MessageData(
                        seq_no=1,
                        created_at=now,
                        data=data,
                        metadata_items={},
                        uncompressed_size=len(data),
                        partitioning=None,
                    )
                ],
            )
        )

        sent_message = await writer_and_stream.stream.from_client.get()
        assert expected_message == sent_message

    async def test_update_token(self, stream: StreamMock):
        writer = await self.get_started_writer(stream, update_token_interval=0.1, get_token_function=lambda: "foo-bar")
        assert stream.from_client.empty()

        expected = StreamWriteMessage.FromClient(UpdateTokenRequest(token="foo-bar"))
        got = await wait_for_fast(stream.from_client.get())
        assert expected == got, "send update token request"

        await asyncio.sleep(0.2)
        assert stream.from_client.empty(), "no answer - no new update request"

        await stream.from_server.put(UpdateTokenResponse())
        receive_task = asyncio.create_task(writer.receive())

        got = await wait_for_fast(stream.from_client.get())
        assert expected == got

        receive_task.cancel()
        await asyncio.wait([receive_task])

        await writer.close()

    async def test_init_timeout_parameter(self, stream):
        """Test that WriterAsyncIOStream._start calls stream.receive with timeout=10"""
        writer_id = 1
        settings = WriterSettings(PublicWriterSettings("test-topic", "test-producer"))

        # Mock stream.receive to check if timeout is passed
        with mock.patch.object(stream, "receive") as mock_receive:
            mock_receive.return_value = StreamWriteMessage.InitResponse(
                last_seq_no=0,
                session_id="test_session",
                partition_id=1,
                supported_codecs=[Codec.CODEC_RAW],
                status=ServerStatus(StatusCode.SUCCESS, []),
            )

            writer = WriterAsyncIOStream(writer_id, settings)
            await writer._start(stream, settings.create_init_request())

            # Verify that receive was called with timeout
            mock_receive.assert_called_with(timeout=DEFAULT_INITIAL_RESPONSE_TIMEOUT)

        await writer.close()

    async def test_init_timeout_behavior(self, stream):
        """Test that WriterAsyncIOStream._start raises TopicWriterError when receive times out"""
        writer_id = 1
        settings = WriterSettings(PublicWriterSettings("test-topic", "test-producer"))

        # Mock stream.receive to directly raise TimeoutError when called with timeout
        async def timeout_receive(timeout=None):
            if timeout == DEFAULT_INITIAL_RESPONSE_TIMEOUT:
                raise asyncio.TimeoutError("Simulated timeout")
            return StreamWriteMessage.InitResponse(
                last_seq_no=0,
                session_id="test_session",
                partition_id=1,
                supported_codecs=[Codec.CODEC_RAW],
                status=ServerStatus(StatusCode.SUCCESS, []),
            )

        with mock.patch.object(stream, "receive", side_effect=timeout_receive):
            writer = WriterAsyncIOStream(writer_id, settings)

            # Should raise TopicWriterError with timeout message
            with pytest.raises(TopicWriterError, match="Timeout waiting for init response"):
                await writer._start(stream, settings.create_init_request())

        # Don't close writer since _start failed and _stream was never set


@pytest.mark.asyncio
class TestWriterAsyncIOReconnector:
    init_last_seqno = 0
    time_for_mocks = 1678046714.639387

    class StreamWriterMock:
        last_seqno: int
        supported_codecs: List[PublicCodec]

        from_client: asyncio.Queue
        from_server: asyncio.Queue

        _closed: bool

        def __init__(
            self,
            update_token_interval: Optional[int, float] = None,
            get_token_function: Optional[Callable[[], str]] = None,
        ):
            self._id = 0
            self.last_seqno = 0
            self.from_server = asyncio.Queue()
            self.from_client = asyncio.Queue()
            self._closed = False
            self.supported_codecs = []

        def write(self, messages: typing.List[InternalMessage]):
            if self._closed:
                raise Exception("write to closed StreamWriterMock")

            self.from_client.put_nowait(messages)

        async def receive(self) -> StreamWriteMessage.WriteResponse:
            if self._closed:
                raise Exception("read from closed StreamWriterMock")

            item = await self.from_server.get()
            if isinstance(item, Exception):
                raise item
            return item

        async def close(self):
            if self._closed:
                return
            self._closed = True

    @pytest.fixture(autouse=True)
    async def stream_writer_double_queue(self, monkeypatch):
        class DoubleQueueWriters:
            _first: Queue
            _second: Queue

            def __init__(self):
                self._first = Queue()
                self._second = Queue()

            def get_first(self):
                try:
                    return self._first.get_nowait()
                except Empty:
                    self._create()
                    return self.get_first()

            def get_second(self):
                try:
                    return self._second.get_nowait()
                except Empty:
                    self._create()
                    return self.get_second()

            def _create(self):
                writer = TestWriterAsyncIOReconnector.StreamWriterMock()
                writer.last_seqno = TestWriterAsyncIOReconnector.init_last_seqno
                self._first.put_nowait(writer)
                self._second.put_nowait(writer)

        res = DoubleQueueWriters()

        async def async_create(driver, init_message, token_getter, tx_identity):
            return res.get_first()

        monkeypatch.setattr(WriterAsyncIOStream, "create", async_create)
        return res

    @pytest.fixture
    def get_stream_writer(
        self, stream_writer_double_queue
    ) -> typing.Callable[[], "TestWriterAsyncIOReconnector.StreamWriterMock"]:
        return stream_writer_double_queue.get_second

    @pytest.fixture
    def default_settings(self) -> WriterSettings:
        return WriterSettings(
            PublicWriterSettings(
                topic="/local/topic",
                producer_id="test-producer",
                auto_seqno=False,
                auto_created_at=False,
                codec=PublicCodec.RAW,
                update_token_interval=3600,
            )
        )

    @pytest.fixture
    def default_write_statistic(
        self,
    ) -> StreamWriteMessage.WriteResponse.WriteStatistics:
        return StreamWriteMessage.WriteResponse.WriteStatistics(
            persisting_time=datetime.timedelta(milliseconds=1),
            min_queue_wait_time=datetime.timedelta(milliseconds=2),
            max_queue_wait_time=datetime.timedelta(milliseconds=3),
            partition_quota_wait_time=datetime.timedelta(milliseconds=4),
            topic_quota_wait_time=datetime.timedelta(milliseconds=5),
        )

    def make_default_ack_message(self, seq_no=1) -> StreamWriteMessage.WriteResponse:
        return StreamWriteMessage.WriteResponse(
            partition_id=1,
            acks=[
                StreamWriteMessage.WriteResponse.WriteAck(
                    seq_no=seq_no,
                    message_write_status=StreamWriteMessage.WriteResponse.WriteAck.StatusWritten(offset=1),
                )
            ],
            write_statistics=self.default_write_statistic,
        )

    @pytest.fixture
    async def reconnector(self, default_driver, default_settings) -> WriterAsyncIOReconnector:
        return WriterAsyncIOReconnector(default_driver, default_settings)

    async def test_reconnect_and_resent_non_acked_messages_on_retriable_error(
        self,
        reconnector: WriterAsyncIOReconnector,
        get_stream_writer,
        default_write_statistic,
    ):
        now = datetime.datetime.now(datetime.timezone.utc)
        data = "123".encode()

        message1 = PublicMessage(
            data=data,
            seqno=1,
            created_at=now,
        )
        message2 = PublicMessage(
            data=data,
            seqno=2,
            created_at=now,
        )
        await reconnector.write_with_ack_future([message1, message2])

        # sent to first stream
        stream_writer = get_stream_writer()

        messages = await stream_writer.from_client.get()
        assert [InternalMessage(message1)] == messages
        messages = await stream_writer.from_client.get()
        assert [InternalMessage(message2)] == messages

        # ack first message
        stream_writer.from_server.put_nowait(self.make_default_ack_message(seq_no=1))

        stream_writer.from_server.put_nowait(issues.Overloaded("test"))

        second_writer = get_stream_writer()
        second_sent_msg = await second_writer.from_client.get()

        expected_messages = [InternalMessage(message2)]
        assert second_sent_msg == expected_messages

        second_writer.from_server.put_nowait(self.make_default_ack_message(seq_no=2))
        await reconnector.close(flush=True)

    async def test_stop_on_unexpected_exception(self, reconnector: WriterAsyncIOReconnector, get_stream_writer):
        class TestException(Exception):
            pass

        stream_writer = get_stream_writer()
        stream_writer.from_server.put_nowait(TestException())

        message = PublicMessage(
            data="123",
            seqno=3,
        )

        with pytest.raises(TestException):

            async def wait_stop():
                while True:
                    await reconnector.write_with_ack_future([message])
                    await asyncio.sleep(0.1)

            await asyncio.wait_for(wait_stop(), 1)

        with pytest.raises(TestException):
            await reconnector.close(flush=False)

    async def test_wait_init(self, default_driver, default_settings, get_stream_writer):
        init_seqno = 100
        expected_init_info = PublicWriterInitInfo(last_seqno=init_seqno, supported_codecs=[])
        with mock.patch.object(TestWriterAsyncIOReconnector, "init_last_seqno", init_seqno):
            reconnector = WriterAsyncIOReconnector(default_driver, default_settings)
            info = await reconnector.wait_init()
            assert info == expected_init_info

        reconnector._stream_connected.clear()

        # force reconnect
        with mock.patch.object(TestWriterAsyncIOReconnector, "init_last_seqno", init_seqno + 1):
            stream_writer = get_stream_writer()
            stream_writer.from_server.put_nowait(issues.Overloaded("test"))  # some retriable error
            await reconnector._stream_connected.wait()

            info = await reconnector.wait_init()
            assert info == expected_init_info

        await reconnector.close(flush=False)

    async def test_write_message(self, reconnector: WriterAsyncIOReconnector, get_stream_writer):
        stream_writer = get_stream_writer()
        message = PublicMessage(
            data="123",
            seqno=3,
        )
        await reconnector.write_with_ack_future([message])

        sent_messages = await asyncio.wait_for(stream_writer.from_client.get(), 1)
        assert sent_messages == [InternalMessage(message)]

        await reconnector.close(flush=False)

    async def test_auto_seq_no(self, default_driver, default_settings, get_stream_writer):
        last_seq_no = 100
        with mock.patch.object(TestWriterAsyncIOReconnector, "init_last_seqno", last_seq_no):
            settings = copy.deepcopy(default_settings)
            settings.auto_seqno = True

            reconnector = WriterAsyncIOReconnector(default_driver, settings)

            await reconnector.write_with_ack_future([PublicMessage(data="123")])
            await reconnector.write_with_ack_future([PublicMessage(data="456")])

            stream_writer = get_stream_writer()

            sent = await stream_writer.from_client.get()
            assert [InternalMessage(PublicMessage(seqno=last_seq_no + 1, data="123"))] == sent

            sent = await stream_writer.from_client.get()
            assert [InternalMessage(PublicMessage(seqno=last_seq_no + 2, data="456"))] == sent

        with pytest.raises(TopicWriterError):
            await reconnector.write_with_ack_future([PublicMessage(seqno=last_seq_no + 3, data="123")])

        await reconnector.close(flush=False)

    async def test_deny_double_seqno(self, reconnector: WriterAsyncIOReconnector, get_stream_writer):
        writer = get_stream_writer()

        await reconnector.write_with_ack_future([PublicMessage(seqno=10, data="123")])
        writer.from_server.put_nowait(self.make_default_ack_message(seq_no=10))

        with pytest.raises(TopicWriterError):
            await reconnector.write_with_ack_future([PublicMessage(seqno=9, data="123")])

        with pytest.raises(TopicWriterError):
            await reconnector.write_with_ack_future([PublicMessage(seqno=10, data="123")])

        await reconnector.write_with_ack_future([PublicMessage(seqno=11, data="123")])
        writer.from_server.put_nowait(self.make_default_ack_message(seq_no=11))

        await reconnector.close(flush=True)

    @freezegun.freeze_time("2022-01-13 20:50:00", tz_offset=0)
    async def test_auto_created_at(self, default_driver, default_settings, get_stream_writer):
        now = datetime.datetime.now(datetime.timezone.utc)

        settings = copy.deepcopy(default_settings)
        settings.auto_created_at = True
        reconnector = WriterAsyncIOReconnector(default_driver, settings)
        await reconnector.write_with_ack_future([PublicMessage(seqno=4, data="123")])

        stream_writer = get_stream_writer()
        sent = await stream_writer.from_client.get()

        assert [InternalMessage(PublicMessage(seqno=4, data="123", created_at=now))] == sent
        await reconnector.close(flush=False)

    @pytest.mark.parametrize(
        "codec,write_datas,expected_codecs,expected_datas",
        [
            (
                PublicCodec.RAW,
                [b"123"],
                [PublicCodec.RAW],
                [b"123"],
            ),
            (
                PublicCodec.GZIP,
                [b"123"],
                [PublicCodec.GZIP],
                [gzip.compress(b"123", mtime=time_for_mocks)],
            ),
            (
                None,
                [b"123", b"456", b"789", b"0" * 1000],
                [PublicCodec.RAW, PublicCodec.GZIP, PublicCodec.RAW, PublicCodec.RAW],
                [
                    b"123",
                    gzip.compress(b"456", mtime=time_for_mocks),
                    b"789",
                    b"0" * 1000,
                ],
            ),
            (
                None,
                [b"123", b"456", b"789" * 1000, b"0"],
                [PublicCodec.RAW, PublicCodec.GZIP, PublicCodec.GZIP, PublicCodec.GZIP],
                [
                    b"123",
                    gzip.compress(b"456", mtime=time_for_mocks),
                    gzip.compress(b"789" * 1000, mtime=time_for_mocks),
                    gzip.compress(b"0", mtime=time_for_mocks),
                ],
            ),
        ],
    )
    async def test_select_codecs(
        self,
        default_driver: aio.Driver,
        default_settings: WriterSettings,
        monkeypatch,
        write_datas: List[typing.Optional[bytes]],
        codec: typing.Optional[PublicCodec],
        expected_codecs: List[PublicCodec],
        expected_datas: List[bytes],
    ):
        assert len(write_datas) == len(expected_datas)
        assert len(expected_codecs) == len(expected_datas)

        settings = copy.copy(default_settings)
        settings.codec = codec
        settings.auto_seqno = True
        reconnector = WriterAsyncIOReconnector(default_driver, settings)

        added_messages = asyncio.Queue()  # type: asyncio.Queue[List[InternalMessage]]

        def add_messages(_self, messages: typing.List[InternalMessage]):
            added_messages.put_nowait(messages)

        monkeypatch.setattr(WriterAsyncIOReconnector, "_add_messages_to_send_queue", add_messages)
        monkeypatch.setattr("time.time", lambda: TestWriterAsyncIOReconnector.time_for_mocks)

        for i in range(len(expected_datas)):
            await reconnector.write_with_ack_future([PublicMessage(data=write_datas[i])])
            mess = await asyncio.wait_for(added_messages.get(), timeout=600)
            mess = mess[0]

            assert mess.codec == expected_codecs[i]
            assert mess.get_data_bytes() == expected_datas[i]

        await reconnector.close(flush=False)

    @pytest.mark.parametrize(
        "codec,datas",
        [
            (
                PublicCodec.RAW,
                [b"123", b"456", b"789", b"0"],
            ),
            (
                PublicCodec.GZIP,
                [b"123", b"456", b"789", b"0"],
            ),
        ],
    )
    async def test_encode_data_inplace(
        self,
        reconnector: WriterAsyncIOReconnector,
        codec: PublicCodec,
        datas: List[bytes],
    ):
        f = reconnector._codec_functions[codec]
        expected_datas = [f(data) for data in datas]

        messages = [InternalMessage(PublicMessage(data)) for data in datas]
        await reconnector._encode_data_inplace(codec, messages)

        for index, mess in enumerate(messages):
            assert mess.codec == codec
            assert mess.get_data_bytes() == expected_datas[index]

        await reconnector.close(flush=True)

    async def test_custom_encoder(self, default_driver, default_settings, get_stream_writer):
        codec = 10001

        settings = copy.copy(default_settings)
        settings.encoders = {codec: lambda x: bytes(reversed(x))}
        settings.codec = codec
        reconnector = WriterAsyncIOReconnector(default_driver, settings)

        now = datetime.datetime.now(datetime.timezone.utc)
        seqno = self.init_last_seqno + 1

        await reconnector.write_with_ack_future([PublicMessage(data=b"123", seqno=seqno, created_at=now)])

        stream_writer = get_stream_writer()
        sent_messages = await wait_for_fast(stream_writer.from_client.get())

        expected_mess = InternalMessage(PublicMessage(data=b"321", seqno=seqno, created_at=now))
        expected_mess.codec = codec

        assert sent_messages == [expected_mess]

        await reconnector.close(flush=False)


@pytest.mark.asyncio
class TestWriterAsyncIO:
    class ReconnectorMock:
        lock: asyncio.Lock
        messages: typing.List[InternalMessage]
        futures: typing.List[asyncio.Future]
        messages_writted: asyncio.Event

        def __init__(self):
            self.lock = asyncio.Lock()
            self.messages = []
            self.futures = []
            self.messages_writted = asyncio.Event()

        async def write_with_ack_future(self, messages: typing.List[InternalMessage]):
            async with self.lock:
                futures = [asyncio.Future() for _ in messages]
                self.messages.extend(messages)
                self.futures.extend(futures)
                self.messages_writted.set()
                return futures

        async def close(self, flush: bool):
            pass

    @pytest.fixture
    def default_settings(self) -> PublicWriterSettings:
        return PublicWriterSettings(
            topic="/local/topic",
            producer_id="producer-id",
        )

    @pytest.fixture(autouse=True)
    def mock_reconnector_init(self, monkeypatch, reconnector):
        def t(cls, driver, settings):
            return reconnector

        monkeypatch.setattr(WriterAsyncIOReconnector, "__new__", t)

    @pytest.fixture
    def reconnector(self, monkeypatch) -> TestWriterAsyncIO.ReconnectorMock:
        reconnector = TestWriterAsyncIO.ReconnectorMock()
        return reconnector

    @pytest.fixture
    async def writer(self, default_driver, default_settings):
        return WriterAsyncIO(default_driver, default_settings)

    async def test_write(self, writer: WriterAsyncIO, reconnector):
        m = PublicMessage(seqno=1, data="123")
        res = await writer.write(m)
        assert res is None

        assert reconnector.messages == [m]

    async def test_write_with_futures(self, writer: WriterAsyncIO, reconnector):
        m = PublicMessage(seqno=1, data="123")
        res = await writer.write_with_ack_future(m)

        assert reconnector.messages == [m]
        assert asyncio.isfuture(res)

    async def test_write_with_ack(self, writer: WriterAsyncIO, reconnector):
        reconnector.messages_writted.clear()

        async def ack_first_message():
            await reconnector.messages_writted.wait()
            async with reconnector.lock:
                reconnector.futures[0].set_result(PublicWriteResult.Written(offset=1))

        asyncio.create_task(ack_first_message())

        m = PublicMessage(seqno=1, data="123")
        res = await writer.write_with_ack(m)

        assert res == PublicWriteResult.Written(offset=1)

        reconnector.messages_writted.clear()
        async with reconnector.lock:
            reconnector.messages.clear()
            reconnector.futures.clear()

        async def ack_next_messages():
            await reconnector.messages_writted.wait()
            async with reconnector.lock:
                reconnector.futures[0].set_result(PublicWriteResult.Written(offset=2))
                reconnector.futures[1].set_result(PublicWriteResult.Skipped())

        asyncio.create_task(ack_next_messages())

        res = await writer.write_with_ack([PublicMessage(seqno=2, data="123"), PublicMessage(seqno=3, data="123")])
        assert res == [PublicWriteResult.Written(offset=2), PublicWriteResult.Skipped()]
